==> plantuml-gplv2-1.2022.5.tar.gz: src/net/sourceforge/plantuml/nwdiag/next/NwArray.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2023, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 *
 * Original Author:  Arnaud Roques
 */
package net.sourceforge.plantuml.nwdiag.next;

public class NwArray {

	private final LinkedElement data[][];

	public NwArray(int lines, int cols) {
		this.data = new LinkedElement[lines][cols];
	}

	public int getNbLines() {
		return data.length;
	}

	public int getNbCols() {
		return data[0].length;
	}

	public LinkedElement get(int i, int j) {
		return data[i][j];
	}

	public LinkedElement[] getLine(int i) {
		return data[i];
	}

	public void set(int i, int j, LinkedElement value) {
		data[i][j] = value;
	}

//	public void swapCols(int col1, int col2) {
//		if (col1 == col2) {
//			throw new IllegalArgumentException();
//		}
//		for (int i = 0; i < getNbLines(); i++) {
//			final LinkedElement tmp = data[i][col1];
//			data[i][col1] = data[i][col2];
//			data[i][col2] = tmp;
//		}
//
//	}
//
//	public Footprint getFootprint(NwGroupLegacy group) {
//		int min = Integer.MAX_VALUE;
//		int max = Integer.MIN_VALUE;
//		for (int i = 0; i < getNbLines(); i++) {
//			for (int j = 0; j < getNbCols(); j++) {
//				if (data[i][j] != null && group.matches(data[i][j])) {
//					min = Math.min(min, j);
//					max = Math.max(max, j);
//				}
//			}
//		}
//		return new Footprint(min, max);
//	}

}

==> plantuml-gplv2-1.2023.5.tar.gz: src/net/sourceforge/plantuml/nwdiag/next/NwArray.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 *
 * Original Author:  Arnaud Roques
 */
package net.sourceforge.plantuml.nwdiag.next;

public class NwArray {
    // ::remove folder when __HAXE__

	private final NServerDraw data[][];

	public NwArray(int lines, int cols) {
		this.data = new NServerDraw[lines][cols];
	}

	@Override
	public String toString() {
		return "lines=" + getNbLines() + " cols=" + getNbCols();
	}

	public int getNbLines() {
		return data.length;
	}

	public int getNbCols() {
		return data[0].length;
	}

	public NServerDraw get(int i, int j) {
		return data[i][j];
	}

	public NServerDraw[] getLine(int i) {
		return data[i];
	}

	public void set(int i, int j, NServerDraw value) {
		data[i][j] = value;
	}

}
